pub fn apply(target: &Path, dryrun: bool, delete_users: bool) -> Result<()>Expand description
Read the config from the given path and apply it to the database. If the dryrun flag is set, the changes will not be applied. If delete_users is true, users in DB but not in config will be deleted.